<?php

/**
 * Account pane: settings form callback.
 *
 * This form provides configuration information for the pane. In this case
 * we set a variable determining whether to request an additional email address.
 */
function commerce_checkbox_checkout_pane_settings_form($checkout_pane) {
  $form = array();
  $form['commerce_checkbox_checkout_pane_id'] = array(
    '#type' => 'machine_name',
    '#title' => t('Checkbox Checkout Pane & Order Data ID'),
    '#description' => t('The ID of this checkout pane. This is also used to store the checkbox value in $order->data. This can not be modified later.'),
    '#default_value' => variable_get('commerce_checkbox_checkout_pane_id', ''),
    '#required' => TRUE,
    '#disabled' => !empty(variable_get('commerce_checkbox_checkout_pane_id')) && $checkout_pane['saved'],
    '#machine_name' => array(
      'exists' => 'commerce_checkbox_checkout_pane_id_exists',
    ),
  );

  $form['commerce_checkbox_checkout_pane_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Checkbox Pane Title'),
    '#description' => t("The title of this checkout pane."),
    '#default_value' => variable_get('commerce_checkbox_checkout_pane_title', 'Checkbox Checkout Pane'),
    '#required' => TRUE,
  );

  $form['commerce_checkbox_checkout_pane_checkbox_label'] = array(
    '#type' => 'textfield',
    '#title' => t('Checkbox Label'),
    '#description' => t("The label of the checkbox."),
    '#default_value' => variable_get('commerce_checkbox_checkout_pane_checkbox_label', ''),
    '#required' => TRUE,
  );

  $form['commerce_checkbox_checkout_pane_checkbox_description'] = array(
    '#type' => 'textarea',
    '#title' => t('Checkbox Description'),
    '#description' => t("The description of the checkbox."),
    '#default_value' => variable_get('commerce_checkbox_checkout_pane_checkbox_description', ''),
    '#required' => FALSE,
  );

  $form['commerce_checkbox_checkout_pane_checkbox_required'] = array(
    '#type' => 'checkbox',
    '#title' => t('Make checkbox required'),
    '#description' => t('If checked, the checkout will not be possible without checking the panes checkbox. For example helpful for GDPR agreements / Opt-In.'),
    '#default_value' => variable_get('commerce_checkbox_checkout_pane_checkbox_required', FALSE),
    '#required' => FALSE,
  );

  return $form;
}

/**
 * Example Pane: form callback.
 *
 * This is a standard FAPI form which will be presented in the pane.
 * The form gathers and stores information from $order->data, an array which
 * can be populated with free-form keys and values.
 */
function commerce_checkbox_checkout_pane_checkout_form($form, &$form_state, $checkout_pane, $order) {
  $pane_form = array();
  $checkbox_data_id = commerce_checkbox_checkout_pane_get_data_id($checkout_pane);
  $pane_form[$checkbox_data_id] = array(
    '#type' => 'checkbox',
    '#title' => filter_xss_admin(variable_get('commerce_checkbox_checkout_pane_checkbox_label', '')),
    '#description' => filter_xss_admin(variable_get('commerce_checkbox_checkout_pane_checkbox_description', '')),
    '#default_value' => !empty($order->data[$checkbox_data_id]) ? $order->data[$checkbox_data_id] : FALSE,
    '#required' => !empty(variable_get('commerce_checkbox_checkout_pane_checkbox_required', FALSE)),
  );

  return $pane_form;
}

function commerce_checkbox_checkout_pane_get_data_id($checkout_pane){
  $id = variable_get('commerce_checkbox_checkout_pane_id', 'checkbox');
  return 'commerce_checkbox_checkout_pane_' . $id . '_checked';
}

/**
 * Example pane: validation callback.
 */
function commerce_checkbox_checkout_pane_checkout_form_validate($form, &$form_state, $checkout_pane, $order) {
  $pane_values = $form_state['values'][$checkout_pane['pane_id']];
  $checkbox_data_id = commerce_checkbox_checkout_pane_get_data_id($checkout_pane);
  $checkbox_is_required = !empty(variable_get('commerce_checkbox_checkout_pane_checkbox_required', FALSE));
  if ($checkbox_is_required && empty($pane_values[$checkbox_data_id])) {
    form_set_error($checkout_pane['pane_id'] . '][' . $checkbox_data_id, t('The "!label" checkbox is required.', array('!label' => filter_xss_admin(variable_get('commerce_checkbox_checkout_pane_checkbox_label', '')))));
    return FALSE;
  }
  return TRUE;
}

/**
 * Example pane: checkout form submission callback.
 */
function commerce_checkbox_checkout_pane_checkout_form_submit($form, &$form_state, $checkout_pane, $order) {
  $checkbox_data_id = commerce_checkbox_checkout_pane_get_data_id($checkout_pane);
  if (!empty($form_state['values'][$checkout_pane['pane_id']])) {
    $pane_values = $form_state['values'][$checkout_pane['pane_id']];

    if (isset($pane_values[$checkbox_data_id])) {
      $order->data[$checkbox_data_id] = $pane_values[$checkbox_data_id];
    }
  }
}

/**
 * Example pane: presents the information we've collected in the Review checkout
 * pane.
 */
function commerce_checkbox_checkout_pane_review($form, $form_state, $checkout_pane, $order) {
  $checkbox_data_id = commerce_checkbox_checkout_pane_get_data_id($checkout_pane);
  $content['commerce_checkbox_checkout_pane_id_review'] = array(
    '#type' => 'item',
    '#title' => filter_xss_admin(variable_get('commerce_checkbox_checkout_pane_checkbox_label', '')) . ':',
    '#markup' => !empty($order->data[$checkbox_data_id]) ? t('Yes') : t('No'),
  );
  return drupal_render($content);
}
